pub struct WccReport {
pub components: Vec<(String, String)>,
pub truncated: bool,
}Expand description
Result of [GraphDb::connected_components].
Fields
components: Vec<(String, String)>Each live node and the key of the smallest member of its component (deterministic component identifier). Sorted by (component_id, key).
truncated: booltrue if the time budget fired before all nodes were processed.