HistoryChange

Enum HistoryChange 

pub enum HistoryChange {
    NodeInserted {
        label: String,
    },
    PropSet {
        field: String,
        value: Value,
    },
    PropRemoved {
        field: String,
    },
    EdgeAdded {
        edge_type: String,
        other: String,
        outgoing: bool,
    },
    EdgeRemoved {
        edge_type: String,
        other: String,
        outgoing: bool,
    },
    NodeDeleted,
}

Variants



NodeInserted

Fields

label: String


PropSet

Fields

field: String
value: Value


PropRemoved

Fields

field: String


EdgeAdded

An edge involving this node was added.

outgoing is true if this node is the source, false if it is the destination.

Self-edges (src == dst == this node) produce a single entry with outgoing: true.

Fields

edge_type: String
other: String
outgoing: bool


EdgeRemoved

An edge involving this node was removed.

outgoing is true if this node is the source, false if it is the destination.

Self-edges (src == dst == this node) produce a single entry with outgoing: true.

Fields

edge_type: String
other: String
outgoing: bool


NodeDeleted