pub struct ExternalHostRuntimeRequest {
pub method: ExternalHostRuntimeMethod,
pub candidate_id: Option<String>,
pub action: Option<String>,
pub payload: Option<Value>,
}Expand description
A platform capability request emitted by an externally hosted Core.
Core owns the onboarding workflow. The native host owns LAN discovery and transport to a discovered candidate, so Android can satisfy this contract without moving application logic into the mobile shell.
Fields
method: ExternalHostRuntimeMethodcandidate_id: Option<String>action: Option<String>payload: Option<Value>Trait Implementations
Sourceimpl Clone for ExternalHostRuntimeRequest
impl Clone for ExternalHostRuntimeRequest
Sourcefn clone(&self) -> ExternalHostRuntimeRequest
fn clone(&self) -> ExternalHostRuntimeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalHostRuntimeRequest
impl Debug for ExternalHostRuntimeRequest
Sourceimpl<'de> Deserialize<'de> for ExternalHostRuntimeRequest
impl<'de> Deserialize<'de> for ExternalHostRuntimeRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more