pub struct RecipientId(/* private fields */);Implementations
Sourceimpl RecipientId
impl RecipientId
Sourcepub fn messaging(
surface: &ConversationSurface,
) -> Result<Self, RecipientIdError>
pub fn messaging( surface: &ConversationSurface, ) -> Result<Self, RecipientIdError>
Convert a validated Messaging surface without losing audience or lane.
pub fn node(node_type: &str, node_id: &str) -> Result<Self, RecipientIdError>
pub fn as_str(&self) -> &str
pub fn messaging_surface(&self) -> Option<ConversationSurface>
Sourcepub fn messaging_base(&self) -> Option<Self>
pub fn messaging_base(&self) -> Option<Self>
The base authorization route excludes a provider topic/lane. This does not change the recipient used for the actual delivery.
pub fn node_address(&self) -> Option<(&str, String)>