pub struct WhatIf {
pub lost: Vec<EdgeAt>,
pub gained: Vec<EdgeAt>,
}Expand description
The derived edges a hypothetical property change would retract and derive.
Returned by GraphDb::what_if_set_prop. Both lists are sorted by
(edge_type, src_key, dst_key) and every entry is rule-derived.
Fields
lost: Vec<EdgeAt>Derived edges that exist now and would be retracted.
gained: Vec<EdgeAt>Derived edges that do not exist now and would be derived.