pub struct NodeRef<'a, F: Fs> { /* private fields */ }Implementations
Sourceimpl<'a, F: Fs> NodeRef<'a, F>
impl<'a, F: Fs> NodeRef<'a, F>
pub fn key(&self) -> &str
pub fn label(&self) -> &str
pub fn prop(&self, field: &str) -> Option<Value>
Sourcepub fn props(&self) -> BTreeMap<String, Value>
pub fn props(&self) -> BTreeMap<String, Value>
All stored fields for this node, sorted by field name.
Reads from the full base+overlay view so that props stored only in the V8 snapshot base (i.e. before any post-snapshot WAL writes) are visible.