pub struct OpenOptions {
pub auto_migrate: bool,
}Expand description
Options for GraphDb::open_with_options.
Fields
auto_migrate: boolRewrite an old-format snapshot to the current VERSION after a
successful load (default true). The old snapshot is kept as
snapshot.bin.bak until the next clean open at the current version,
at which point the .bak is deleted.
Set to false to open a store without touching any on-disk files
(useful for read-only inspection of a store at an older format).